diff scripts/image/colormap.m @ 6895:76e3d985ae56

[project @ 2007-09-13 18:22:38 by jwe]
author jwe
date Thu, 13 Sep 2007 18:22:51 +0000
parents 721953d49b19
children 93c65f2a5668
line wrap: on
line diff
--- a/scripts/image/colormap.m	Thu Sep 13 16:36:18 2007 +0000
+++ b/scripts/image/colormap.m	Thu Sep 13 18:22:51 2007 +0000
@@ -27,10 +27,11 @@
 ## contain red, green, and blue intensities respectively.  All entries
 ## should be between 0 and 1 inclusive.  The new colormap is returned.
 ##
 ## @code{colormap ("default")} restores the default colormap (a gray scale
 ## colormap with 64 entries).  The default colormap is returned.
 ##
 ## With no arguments, @code{colormap} returns the current color map.
+## @seealso{jet}
 ## @end deftypefn
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
@@ -49,7 +50,7 @@
 
     if (ischar (map))
       if (strcmp (map, "default"))
-        map = __default_colormap__ ();
+        map = jet (64);
       else
         map = feval (map);
       endif
@@ -27,10 +27,11 @@
 ## should be between 0 and 1 inclusive.  The new colormap is returned.
 ##
-## @code{colormap ("default")} restores the default colormap (a gray scale
-## colormap with 64 entries).  The default colormap is returned.
+## @code{colormap ("default")} restores the default colormap (the
+## @code{jet} map with 64 entries).  The default colormap is returned.
 ##
 ## With no arguments, @code{colormap} returns the current color map.